@@ -1,17 +1,20 @@
-from typing import TypeVar
+"""Houses Base Authorization Handler"""
 
-# internal imports
+from typing import TypeVar
 from pyrestsdk.credential import AbstractCredential
 from pyrestsdk.middleware._base_middleware import BaseMiddleware
 
-C = TypeVar('C', bound=AbstractCredential)
-A = TypeVar('A', bound='BaseAuthorizationHandler')
+C = TypeVar("C", bound=AbstractCredential)
+A = TypeVar("A", bound="BaseAuthorizationHandler")
+
 
 class BaseAuthorizationHandler(BaseMiddleware):
+    """Base Authorization Handler Type"""
 
     credential: C
-    retry_count: int = 0
+    retry_count: int
 
-    def __init__(self, credential: C, **kwargs):
+    def __init__(self, credential: C, /):
         super().__init__()
         self.credential = credential
+        self.retry_count = 0
