@@ -11,7 +11,7 @@ def test_client_factory_with_custom_middleware():
         BaseAuthorizationHandler(None)
     ]
     
-    client = HTTPClientFactory(Session()).create_with_custom_middleware(middleware)
+    client = HTTPClientFactory("google.com",Session()).create_with_custom_middleware(middleware)
     
     response = client.get("https://www.google.com")
     
